@@ -1,26 +1,20 @@
 #!/bin/bash
 set -e -x
 
-if [ x${OLDPY} == x ]; then
-	PYTHON=python
-else
-	PYTHON=${OLDPY}
-	export PYTHONPATH=${PWD}/custom_packages
-fi
+export CFLAGS+=" -Wconversion"
+ARCH=`uname -m`
 
-echo ${PYTHON}
-
-PYVERSION=$(${PYTHON} -V 2>&1)
+PYVERSION=$(python -V 2>&1)
 echo ${PYVERSION}
 
-${PYTHON} -c "import cffi" 2>/dev/null && echo CFFI is installed || true
+python -c "import cffi" 2>/dev/null && echo CFFI is installed || true
 
 if [ x${CFFI} = "xyes" ]; then
-	${PYTHON} -c"import cffi"
+	python -c"import cffi"
 fi
 
 if [ x${CFFI} != "xyes" ]; then
-	! ${PYTHON} -c"import cffi" 2>/dev/null
+	! python -c"import cffi" 2>/dev/null
 fi
 
 MAJOR=$(echo ${PYVERSION} | cut -f2 -d' ' | cut -f1 -d'.')
@@ -33,7 +27,11 @@ if [[ ${PYVERSION} != *"PyPy"* ]] || [ "${MAJOR}" -lt 3 ]; then
 	xflags="$xflags -tt"
 fi
 
+if [[ "$ARCH" = "aarch64" ]]; then
+	testflags="$testflags --skip-slow-tests"
+fi
+
 echo "Custom Python flags:" \"${xflags:-none}\"
 
-${PYTHON} $xflags setup.py build
-${PYTHON} $xflags setup.py test
+python $xflags setup.py build
+python $xflags setup.py test $testflags
